@@ -1,6 +1,5 @@
 package org.ovirt.vdsm.jsonrpc.client.reactors;
 
-import static org.ovirt.vdsm.jsonrpc.client.utils.JsonUtils.getCauseMessage;
 import static org.ovirt.vdsm.jsonrpc.client.utils.JsonUtils.getTimeout;
 import static org.ovirt.vdsm.jsonrpc.client.utils.JsonUtils.logException;
 
@@ -25,6 +24,7 @@ import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.locks.Lock;
 import java.util.concurrent.locks.ReentrantLock;
 
+import org.apache.commons.lang.exception.ExceptionUtils;
 import org.ovirt.vdsm.jsonrpc.client.ClientConnectionException;
 import org.ovirt.vdsm.jsonrpc.client.internal.ClientPolicy;
 import org.ovirt.vdsm.jsonrpc.client.utils.LockWrapper;
@@ -134,7 +134,7 @@ public abstract class ReactorClient {
             postConnect(getPostConnectCallback());
         } catch (InterruptedException | ExecutionException e) {
             logException(log, "Exception during connection", e);
-            final String message = "Connection issue " + getCauseMessage(e);
+            final String message = "Connection issue " + ExceptionUtils.getRootCause(e).getMessage();
             scheduleClose(message);
             throw new ClientConnectionException(e);
         } catch (IOException e) {
@@ -214,16 +214,11 @@ public abstract class ReactorClient {
 
     private void processHeartbeat() {
         if (!this.isInInit() && this.policy.isIncomingHeartbeat() && this.isIncomingHeartbeatExeeded()) {
-            log.error("Heartbeat exceeded for host '{}', last response arrived {} ms ago.", getHostname(),
-                    getHeartbeatTime());
+            log.debug("Heartbeat exceeded. Closing channel");
             this.disconnect("Heartbeat exceeded");
         }
     }
 
-    private long getHeartbeatTime() {
-        return System.currentTimeMillis() - (this.lastIncomingHeartbeat + this.policy.getIncomingHeartbeat());
-    }
-
     private boolean isIncomingHeartbeatExeeded() {
         return this.lastIncomingHeartbeat + this.policy.getIncomingHeartbeat() < System.currentTimeMillis();
     }
